==> gsp-0.5.0.tgz: package/lib/preprocessors/sass.js <==
'use strict';

var chalk = require('chalk');
var sass = require('node-sass');

var rsass = /\.sass$/;
var rimport = /^@import\s/m;

var compilesass = function compilesass(filedata, callback) {
    if (rimport.test(filedata)) {
        callback(new Error('sass import directives are not supported'));
        return;
    }
    sass.render({ data: filedata }, function (err, data) {
        if (err) {
            var column = err.column;
            var line = err.line - 1;
            var codeLine = filedata.split('\n')[line];
            var offendingCharacter = undefined;
            var errMsg = undefined;

            if (column < codeLine.length) {
                offendingCharacter = chalk.red(codeLine[column - 1]);
            } else {
                offendingCharacter = '';
            }

            line += 1;
            errMsg = '[sass]:' + line + ':' + column + ': ' + err.message;
            errMsg += '\n' + codeLine.substring(0, column - 1) + offendingCharacter + codeLine.substring(column);
            errMsg += '\n' + new Array(column).join(' ') + chalk.red('^');
            err = new Error(errMsg);
            callback(err);
        } else {
            callback(null, data.css);
        }
    });
};

module.exports = function (file, callback) {
    compilesass(file.get('filedata'), function (err, filedata) {
        if (!err) {
            file.set('filename', file.get('filename').replace(rsass, '.css'));
            file.set('filedata', filedata);
        }
        callback(err);
    });
};

==> gsp-0.5.4.tgz: package/lib/preprocessors/sass.js <==
'use strict';

var chalk = require('chalk');
var sass = require('node-sass');
var path = require('path');

var rsass = /\.(?:sass|scss)$/;

var compilesass = function compilesass(workdir, filename, filedata, callback) {
    sass.render({
        file: path.join(workdir, filename)
    }, function (err, data) {
        if (err) {
            var column = err.column;
            var line = err.line - 1;
            var codeLine = filedata.split('\n')[line];
            var offendingCharacter = undefined;
            var errMsg = undefined;

            if (column < codeLine.length) {
                offendingCharacter = chalk.red(codeLine[column - 1]);
            } else {
                offendingCharacter = '';
            }

            line += 1;
            errMsg = '[sass]:' + line + ':' + column + ': ' + err.message;
            errMsg += '\n' + codeLine.substring(0, column - 1) + offendingCharacter + codeLine.substring(column);
            errMsg += '\n' + new Array(column).join(' ') + chalk.red('^');
            err = new Error(errMsg);
            callback(err);
        } else {
            callback(null, data.css);
        }
    });
};

module.exports = function (file, callback) {
    compilesass(file.get('workdir'), file.get('filename'), file.get('filedata'), function (err, filedata) {
        if (!err) {
            file.set('filename', file.get('filename').replace(rsass, '.css'));
            file.set('filedata', filedata);
        }
        callback(err);
    });
};
